#!/bin/bash
# Line above doe not correctly work for this script symlinks
#SCRIPT_DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
# And symlinks are not working on windows.
SCRIPT_DIR="$(realpath $(dirname "$(readlink -f "$0")"))"

set -e

. $SCRIPT_DIR/_helpers.sh || {
  echo "no helpers" && exit 1
}

cd "$SCRIPT_DIR/.."

PHP_VERSION=$1

if [[ -z "${PHP_VERSION}" ]]; then PHP_VERSION=81; fi

WITH_PROFILER=$2

PHP_DOT_VERSION=$(dot_version ${PHP_VERSION})

PHP_FPM_CONTAINER=$(docker ps | grep "php${PHP_VERSION}" | awk '{print $1}')
WORKSPACE_CONTAINER=$(docker ps | grep "workspace${PHP_VERSION}" | awk '{print $1}')

PHP_FPM_XDEBUG_EXT_PATH=/usr/local/etc/php/conf.d/docker-php-ext-xdebug.ini
WORKSPACE_XDEBUG_EXT_PATH=/etc/php/${PHP_DOT_VERSION}/cli/conf.d/20-xdebug.ini

PHP_FPM_XDEBUG_CONFIG_PATH=/usr/local/etc/php/conf.d/xdebug.ini
WORKSPACE_XDEBUG_CONFIG_PATH=/etc/php/${PHP_DOT_VERSION}/cli/conf.d/xdebug.ini

SED_XDEBUG_ON="sed -i 's/^;zend_extension=/zend_extension=/g'"

docker exec -it "${PHP_FPM_CONTAINER}" bash -c "${SED_XDEBUG_ON} ${PHP_FPM_XDEBUG_EXT_PATH}"
docker exec -it "${WORKSPACE_CONTAINER}" bash -c "${SED_XDEBUG_ON} ${WORKSPACE_XDEBUG_EXT_PATH}"

echo "Turn on xdebug: $PHP_VERSION"

if [ -n "${WITH_PROFILER}" ]; then
  echo "Profiler enabled"
  if [ "${PHP_VERSION}" = 74 ]; then
    SED_DEBUG_OR_PROFILER_MODE_ON="sed -i 's/^xdebug.profiler_enable=.*/xdebug.profiler_enable=1/g'"
  else
    SED_DEBUG_OR_PROFILER_MODE_ON="sed -i 's/^xdebug.mode=.*/xdebug.mode=profile/g'"
  fi
elif [ "${PHP_VERSION}" -ne 74 ]; then
  SED_DEBUG_OR_PROFILER_MODE_ON="sed -i 's/^xdebug.mode=.*/xdebug.mode=debug/g'"
fi

if [ -n "${SED_DEBUG_OR_PROFILER_MODE_ON}" ]; then
  docker exec -it "${PHP_FPM_CONTAINER}" bash -c "${SED_DEBUG_OR_PROFILER_MODE_ON} ${PHP_FPM_XDEBUG_CONFIG_PATH}"
  docker exec -it "${WORKSPACE_CONTAINER}" bash -c "${SED_DEBUG_OR_PROFILER_MODE_ON} ${WORKSPACE_XDEBUG_CONFIG_PATH}"
fi

docker restart "${PHP_FPM_CONTAINER}"

echo 'Use this for resolve hostname in your IDE debugger:'
echo 'export PHP_IDE_CONFIG="serverName=myproject.cli.local.wpstudio.ru"'
