###########################################################################
# Laradock non-root user:
###########################################################################

# Thath might be changed in structure/dockerfiles and structure/.env
ARG PUID=1000
ARG PGID=1000

# For more infromation about set command: See https://www.gnu.org/software/bash/manual/html_node/The-Set-Builtin.html
# RUN set -xe

RUN groupadd -g ${PGID} laradock && \
    useradd -u ${PUID} -g laradock -m laradock -G docker_env && \
    usermod -p "*" laradock -s /bin/bash

ARG DEBIAN_FRONTEND=noninteractive
ARG DEBCONF_NOWARNINGS=yes

RUN apt -qq update && \
    apt-get install tmux bash-completion inetutils-ping -qq

###########################################################################
# Install PHP-extensions:
###########################################################################

ARG EXTS=(bz2)

SHELL ["/bin/bash", "-c"]
RUN for EXT in ${EXTS[@]}; do apt-get install -qq php${PHP_VERSION}-${EXT}; done
SHELL ["/bin/sh", "-c"]

###########################################################################
# xDebug:
###########################################################################

RUN PHP_MAJOR_VERSION=$(php -r 'echo PHP_MAJOR_VERSION;') && \
    PHP_MINOR_VERSION=$(php -r 'echo PHP_MINOR_VERSION;') && \
    if [ $PHP_MAJOR_VERSION = '8' ]; then \
      pecl install xdebug-3.4.1; \
    elif [ $PHP_MAJOR_VERSION = '7' ]; then \
      pecl install xdebug-2.9.8; \
    else \
      echo "Not support that major PHP version: $PHP_MAJOR_VERSION"; \
      exit 1; \
    fi && \
    echo ';zend_extension=xdebug.so' > /etc/php/${PHP_VERSION}/cli/conf.d/20-xdebug.ini

###########################################################################
# Redis:
###########################################################################

RUN echo '' | pecl install redis && \
    echo "extension=redis.so" > /etc/php/${PHP_VERSION}/cli/conf.d/20-redis.ini

###########################################################################
# Check PHP version:
###########################################################################

RUN php -v | head -n 1 | grep -q "PHP ${PHP_VERSION}."

###########################################################################
# Tune opts:
###########################################################################

ARG PHP_OPT_MEMORY_LIMIT=256M
RUN sed -i "s/^memory_limit = .*/memory_limit = $PHP_OPT_MEMORY_LIMIT/g" /etc/php/${PHP_VERSION}/cli/php.ini

#
#--------------------------------------------------------------------------
# Final Touch
#--------------------------------------------------------------------------
#

# Clean up
RUN apt clean && \
    rm -rf /var/lib/apt/lists/* /tmp/* /var/tmp/* && \
    rm /var/log/lastlog /var/log/faillog

# Set default work directory
WORKDIR /var/www
